summaryrefslogtreecommitdiffstats
path: root/tdeui/kdockwidget.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:13:01 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:13:01 -0600
commitdeac2ca49faed824fe83066080714eb6d653615b (patch)
tree8b5bf97c5acaaf5285985b87fa76dbea0f35e4fa /tdeui/kdockwidget.h
parent0c9d97065a3d6ceb12d687555a1a33d90db96238 (diff)
downloadtdelibs-deac2ca49faed824fe83066080714eb6d653615b.tar.gz
tdelibs-deac2ca49faed824fe83066080714eb6d653615b.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'tdeui/kdockwidget.h')
-rw-r--r--tdeui/kdockwidget.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/tdeui/kdockwidget.h b/tdeui/kdockwidget.h
index 27b7f2b74..7d52d354c 100644
--- a/tdeui/kdockwidget.h
+++ b/tdeui/kdockwidget.h
@@ -36,7 +36,7 @@
- KDockTabGroup - minor helper class
- KDockWidget - IMPORTANT CLASS: the one and only dockwidget class
- KDockManager - helper class
- - KDockMainWindow - IMPORTANT CLASS: a special KMainWindow that can have dockwidgets
+ - KDockMainWindow - IMPORTANT CLASS: a special TDEMainWindow that can have dockwidgets
- KDockArea - like KDockMainWindow but inherits just QWidget
IMPORTANT Note: This file compiles also in Qt-only mode by using the NO_KDE2 precompiler definition!
@@ -80,7 +80,7 @@ class TQHBoxLayout;
class TQPixmap;
#ifndef NO_KDE2
-class KToolBar;
+class TDEToolBar;
class TDEConfig;
#else
class TQToolBar;
@@ -1269,7 +1269,7 @@ private:
};
/**
* A special kind of KMainWindow that is able to have dockwidget child widgets (and member of the dockwidget class set).
*
* The main widget should be a KDockWidget where other KDockWidget can be docked to
* the left, right, top, bottom or to the middle.
@@ -1311,7 +1311,7 @@ private:
*
* @author Max Judin (documentation: Falk Brettschneider).
*/
-class TDEUI_EXPORT KDockMainWindow : public KMainWindow
+class TDEUI_EXPORT KDockMainWindow : public TDEMainWindow
{
Q_OBJECT
@@ -1269,7 +1269,7 @@ private:
};
/**
- * A special kind of KMainWindow that is able to have dockwidget child widgets (and member of the dockwidget class set).
+ * A special kind of TDEMainWindow that is able to have dockwidget child widgets (and member of the dockwidget class set).
*
* The main widget should be a KDockWidget where other KDockWidget can be docked to